package com.alternative;

import junit.framework.Assert;
import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.OperateOnDeployment;
import org.jboss.arquillian.container.test.api.OverProtocol;
import org.jboss.arquillian.container.test.api.TargetsContainer;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.shrinkwrap.api.Archive;
import org.jboss.shrinkwrap.api.ArchivePaths;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.spec.EnterpriseArchive;
import org.jboss.shrinkwrap.api.spec.JavaArchive;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.Test;
import org.junit.runner.RunWith;

import javax.inject.Inject;

/**
 * @author Roman Boris
 * @since 3/5/12
 */
@RunWith(Arquillian.class)
public class AppTest extends Assert
{
	@Deployment
//	@OverProtocol("EJB 3.1")
	public static Archive<?> createTestArchive()
	{
		return createArchive();
	}

	protected static Archive<?> createArchive()
	{
		EnterpriseArchive archive =
			ShrinkWrap.create(EnterpriseArchive.class, "AppTest.ear")
				.addAsModule(createEjbArchive("App-ejb.jar"))
				.addAsModule(createWarArchive("App-war.war"))
				.addAsManifestResource(
					"META-INF/glassfish-resources-test.xml",
					ArchivePaths.create("glassfish-resources.xml"));

		return archive;
	}

	protected static Archive<?> createEjbArchive(String name)
	{
		JavaArchive archive =
			ShrinkWrap.create(JavaArchive.class, name)
				.addPackages(true, "com.alternative")
				.addAsManifestResource("META-INF/ejb-jar.xml", ArchivePaths.create("ejb-jar.xml"))
				.addAsManifestResource("META-INF/beans.xml", ArchivePaths.create("beans.xml"));

		return archive;
	}

	protected static Archive<?> createWarArchive(String name)
	{
		WebArchive archive =
			ShrinkWrap.create(WebArchive.class, name)
				.addAsWebInfResource("META-INF/beans.xml", ArchivePaths.create("beans.xml"));

		return archive;
	}

	@Inject
	private MyBeanInterface injected;

	@Test
	public void testApplication()
	{
		assertEquals("propertyValue", injected.getProperty());
	}
}
